==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>貼り付けエンティティを回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>貼り付けエンティティを拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>オリジナルの画層の代わりに&lt;br&gt;全てのエンティティを現在の画層に&lt;br&gt;貼り付け</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>現在の画層へ</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存の画層に上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>画層に上書き</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存のブロックに上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>ブロックに上書き</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;P 貼り付け</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>貼り付けエンティティを回転&lt;br&gt;この角度で</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>貼り付けエンティティを拡縮&lt;br&gt;この係数で</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;水平</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>貼り付けエンティティを反転&lt;br&gt;垂直</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>オリジナルの画層の代わりに&lt;br&gt;全てのエンティティを現在の画層に&lt;br&gt;貼り付け</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>現在の画層へ</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存の画層に上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>画層に上書き</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>クリップボードから図面の&lt;br&gt;既存のブロックに上書き</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>ブロックに上書き</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;P 貼り付け</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>ツールを使用するたびにデフォルトにリセット</translation>
    </message>
</context>
</TS>
